export declare type LogLevel = 'fatal' | 'emerg' | 'alert' | 'crit' | 'error' | 'warning' | 'warn' | 'notice' | 'info' | 'verbose' | 'log' | 'debug' | 'trace' | 'silly';
export interface LogDetails {
    [k: string]: any;
}
export declare type LogPrimitive = (message?: string, details?: Readonly<LogDetails>) => void;
export interface Logger {
    setLevel: (level: LogLevel) => void;
    getLevel: () => LogLevel;
    addCommonDetails: (hash: Readonly<LogDetails>) => void;
    fatal: LogPrimitive;
    emerg: LogPrimitive;
    alert: LogPrimitive;
    crit: LogPrimitive;
    error: LogPrimitive;
    warning: LogPrimitive;
    warn: LogPrimitive;
    notice: LogPrimitive;
    info: LogPrimitive;
    verbose: LogPrimitive;
    log: LogPrimitive;
    debug: LogPrimitive;
    trace: LogPrimitive;
    silly: LogPrimitive;
    group(groupTitle?: string): void;
    groupCollapsed(groupTitle?: string): void;
    groupEnd(): void;
}
export interface LogPayload {
    level: LogLevel;
    name: string;
    msg: string;
    time: number;
    err?: Error;
    details: LogDetails;
}
export declare type LogSink = (payload: LogPayload) => void;
export interface BaseInternalLoggerState {
    name: string;
    level: LogLevel;
    commonDetails: LogDetails;
    outputFn: LogSink;
}
export interface LoggerCreationParams {
    name?: string;
    suggestedLevel?: LogLevel;
    commonDetails?: Readonly<LogDetails>;
}
